
To do
=====

As part of its analysis pylint will highlight places in curves where work is flagged as ``TODO: #)``.
These numbers roughly correspond to:

1. Major feature.
2. Minor feature.
3. Performance.
4. Miscellaneous, usually writing up proofs of correctness.

Currently there are no major features left to implement.
